Function error_info::summary
source · pub fn summary() -> Vec<ErrorInfoSummary>Expand description
Retrieves a summary of every ErrorInfo declared, sorted by status and code.
This could be exported to provide the base i18n file for errors.
pub fn summary() -> Vec<ErrorInfoSummary>Retrieves a summary of every ErrorInfo declared, sorted by status and code.
This could be exported to provide the base i18n file for errors.